# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-28 18:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0024_auto_20170328_1751'),
    ]

    operations = [
        migrations.AlterField(
            model_name='categoryitem',
            name='itemTemplate',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='omCmsMain.itemLayout', to_field='itemLayoutName'),
        ),
    ]
