# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-22 20:24
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0008_auto_20170322_2004'),
    ]

    operations = [
        migrations.CreateModel(
            name='itemLayout',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('itemLayoutName', models.CharField(max_length=50, unique=True)),
                ('itemLayoutDescriptio', models.CharField(blank=True, max_length=150, null=True)),
            ],
        ),
        migrations.RenameField(
            model_name='categoryitem',
            old_name='itemStyle',
            new_name='itemTemplate',
        ),
        migrations.AddField(
            model_name='categoryitem',
            name='onMouseOverDescription',
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='categoryitem',
            name='itemLayout',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='omCmsMain.itemLayout', to_field='itemLayoutName'),
            preserve_default=False,
        ),
    ]
