# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-20 21:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0003_auto_20170320_1540'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteAdress',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteAnalytics',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteEmail',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteHeadBgImg',
            field=models.ImageField(blank=True, null=True, upload_to='media/omCmsMain/siteImages'),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteLogo',
            field=models.ImageField(blank=True, null=True, upload_to='media/omCmsMain/siteImages'),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteLongDescription',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteName',
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='sitePhone1',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='sitePhone2',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteShortDescription',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteTagLine1',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteTagLine2',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
    ]
