# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-26 19:06
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0020_auto_20170323_1337'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteHeaderWidth',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteHeadrHeigth',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteLogoHeigth',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
        migrations.AddField(
            model_name='sitemaininfo',
            name='siteLogoWidth',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteHeadBgImg',
            field=models.ImageField(blank=True, null=True, upload_to='siteImages/'),
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteLogo',
            field=models.ImageField(blank=True, null=True, upload_to='siteImages/'),
        ),
        migrations.AlterField(
            model_name='sitesocialmediareference',
            name='smLogo',
            field=models.ImageField(null=True, upload_to='socialMediaImages/'),
        ),
    ]
