
                <div class="col-md-4 col-sm-6">
                    <div class="single-about-detail clearfix">
                        <div class="about-img">
                            <!--img class="img-responsive" src="_/static/main/img/item1.jpg" alt=""-->
                        </div>
                        <div class="about-details">
                            <div class="pentagon-text">
                                <h1>{{articleitem.order}}</h1>
                            </div>
                            <h3>{{articleitem.title}}</h3>
                            <h4>{{articleitem.subTitle}}</h4>
                            <p>{{articleitem.teaser}}</p>
                        </div>
                    </div>
                </div>
                
