# Local Settings for omCmsMain
# To be included in project settings

STATIC_URL = '/static/'
MEDIA_ROOT = '/home/rtavares/DATA/develop/python/django/omCms/omCms/omCmsMain/media/omCmsMain'
MEDIA_URL = '/media/'

print "MEDIA_URL: ", MEDIA_URL

EMAIL_USE_TLS = True
EMAIL_HOST = 'smtp.gmail.com'
EMAIL_PORT = 587
EMAIL_HOST_USER = 'register.me.alubrat2017@gmail.com'
EMAIL_HOST_PASSWORD = '#Login2017'
