{% load static %}

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <title>{% block head-title %}Base Title{% endblock %}</title>

    {% static "" as staticBaseUrl %}

    <!-- jQuery  -->
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.1.1/jquery.js"></script>

    <!-- BootStrap -->
    <!-- Latest compiled and minified CSS -->
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.min.css" integrity="sha384-BVYiiSIFeK1dGmJRAkycuHAHRg32OmUcww7on3RYdg4Va+PmSTsz/K68vbdEjh4u" crossorigin="anonymous" />

    <!-- Optional theme -->
    <!--link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap-theme.min.css" integrity="sha384-rHyoN1iRsVXV4nD0JutlnGaslCJuC7uwjduW9SVrLvRYooPp2bWYgmgJQIXwl/Sp" crossorigin="anonymous" /-->

    <!-- Font Awsome CSS -->
    <link rel="stylesheet" href="{{staticBaseUrl}}/omCmsMain/css/font-awesome.min.css" />

    <link href='http://fonts.googleapis.com/css?family=Open+Sans:600italic,400,800,700,300' rel='stylesheet' type='text/css'>
    <link href='http://fonts.googleapis.com/css?family=BenchNine:300,400,700' rel='stylesheet' type='text/css'>
    
    <script src="{{staticBaseUrl}}omCmsMain/js/modernizr.js"></script>
    <!--[if lt IE 9]>
      <script src="{{staticBaseUrl}}js/html5shiv.js"></script>
      <script src="{{staticBaseUrl}}js/respond.min.js"></script>
    <![endif]-->


    <!-- Load Theme Styles CSS, if defined -->
    {% if siteInfoData.siteTheme %}
        <link rel="stylesheet" href="{{staticBaseUrl}}omCmsMain/css/theme/{{siteInfoData.siteTheme}}/themeStyle.css" />
    {% endif %}

    <!-- Local Styles CSS -->
    <link rel="stylesheet" href="{{staticBaseUrl}}/omCmsMain/css/omCmsStyle.css" />

    {% block head-js-analytics %}<script>/* Place for Google Analytics*/</script>{% endblock %}
    

</head>
<body>
  {% block body-header %}Body Header{% endblock %}
  {% block body-main %}Bosy Main {% endblock %}
  {% block body-footer %}Body Footer{% endblock %}

    <!-- script tags
    ============================================================= -->
    <!-- Latest compiled and minified JavaScript -->
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/js/bootstrap.min.js" integrity="sha384-Tc5IQib027qvyjSMfHjOMaLkfuWVxZxUPnCJA7l2mCWNIpG9mGCD8wGNIcPD7Txa" crossorigin="anonymous">
    </script>    

    <script src="http://maps.google.com/maps/api/js?sensor=true"></script>
    <script src="{{staticBaseUrl}}omCmsMain/js/gmaps.js"></script>
    <!--script src="{{staticBaseUrl}}omCmsMain/js/smoothscroll.js"></script-->
    <script src="{{staticBaseUrl}}omCmsMain/js/custom.js"></script>

</body>
</html>