# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-10 12:13
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0029_auto_20170406_2203'),
    ]

    operations = [
        migrations.CreateModel(
            name='theme',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('themeName', models.CharField(max_length=50, unique=True)),
                ('themeDescription', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.AlterField(
            model_name='sitemaininfo',
            name='siteTheme',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='omCmsMain.theme', to_field='themeName'),
        ),
    ]
