

                <div class="col-md-4 col-sm-6">
                    <div class="single-about-detail clearfix">
                        <div class="about-img">
                            <!--img class="img-responsive" src="_/static/main/img/item1.jpg" alt=""-->
                        </div>
                        <div class="about-details">
                            <h4>{% if articleitem.title1 %}{{articleitem.title1}}{% endif %}</h4>
                            <p>{{articleitem.body1|safe}}</p>
                        </div>
                    </div>
                </div>

                <div class="col-md-4 col-sm-6">
                    <div class="single-about-detail clearfix">
                        <div class="about-img">
                            <!--img class="img-responsive" src="_/static/main/img/item1.jpg" alt=""-->
                        </div>
                        <div class="about-details">
                            <h4>{% if articleitem.title2 %}{{articleitem.title2}}{% endif %}</h4>
                            <p>{{articleitem.body2|safe}}</p>
                        </div>
                    </div>
                </div>

                <div class="col-md-4 col-sm-6">
                    <div class="single-about-detail clearfix">
                        <div class="about-img">
                            <!--img class="img-responsive" src="_/static/main/img/item1.jpg" alt=""-->
                        </div>
                        <div class="about-details">
                            <h4>{% if articleitem.title3 %}{{articleitem.title3}}{% endif %}</h4>
                            <p>{{articleitem.body3|safe}}</p>
                        </div>
                    </div>
                </div>
