
<div class="mdl-grid portfolio-max-width">
    <div class="mdl-cell mdl-cell--12-col mdl-card mdl-shadow--4dp">
        <!-- Ctegory Reference -->
        <!--div class="mdl-card__actions mdl-card--border">
            <a class="mdl-button mdl-button--colored mdl-js-button mdl-js-ripple-effect mdl-button--accent" href="/#{{category}}">{{category}}</a>
        </div-->

        <div class="mdl-card__title">
            <h2 class="mdl-card__title-text">{{article.title|safe|linebreaks}}</h2>
        </div>
        
        {% if article.teaserImage %}
            <div class="_mdl-card__media">
                <img class="article-image_" src="{{article.teaserImage.url}}" border="0" title="{{article.title}}" alt="{{article.title}}">
            </div>
        {% endif %}

        <div class="mdl-grid portfolio-copy">
            <h3 class="mdl-cell mdl-cell--12-col mdl-typography--headline">{{article.subTitle|safe|linebreaks}}</h3>
            <h4 class="mdl-cell mdl-cell--12-col mdl-typography--headline">{{article.teaser|safe|linebreaks}}</h4>
        </div>    
        <div class="mdl-grid portfolio-copy">
            <h4 class="mdl-cell mdl-cell--12-col mdl-typography--headline">{% if article.title1 %}{{article.title1|safe|linebreaks}}{% endif %}</h4>
            {% if articleitem.body1Image %}
                <div class="mdl-card__media">
                    <img class="article-image" src="{{articleitem.body1Image.url}}" border="0" alt="">
                </div>
            {% endif %}
            <div class="mdl-cell mdl-cell--12-col mdl-card__supporting-text no-padding ">
                <p>
                    {% if article.body1 %}{{article.body1|safe|linebreaks}}{% endif %}
                </p>
            </div>

        </div>
    </div>
</div>