# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-22 22:41
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0015_auto_20170322_2232'),
    ]

    operations = [
        migrations.AddField(
            model_name='categoryitem',
            name='itemsByLine',
            field=models.IntegerField(blank=True, default=0, null=True),
        ),
    ]
