# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-28 17:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0023_auto_20170328_1731'),
    ]

    operations = [
        migrations.AddField(
            model_name='itemlayout',
            name='itemLayoutSortDescription',
            field=models.CharField(blank=True, max_length=150, null=True),
        ),
        migrations.AlterField(
            model_name='itemlayout',
            name='itemLayoutDescription',
            field=models.TextField(blank=True, null=True),
        ),
    ]
