# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-22 19:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0006_sitemaininfo_active'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitemaininfo',
            name='recordReference',
            field=models.CharField(default='First', max_length=50, unique=True),
            preserve_default=False,
        ),
    ]
