# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-20 15:32
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0001_initial'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='categoryItems',
            new_name='categoryItem',
        ),
        migrations.RenameModel(
            old_name='siteSocialMediaReferences',
            new_name='siteSocialMediaReference',
        ),
    ]
