# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-22 20:32
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0011_auto_20170322_2029'),
    ]

    operations = [
        migrations.RenameField(
            model_name='itemlayout',
            old_name='itemLayoutDescriptio',
            new_name='itemLayoutDescription',
        ),
    ]
