# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-04-05 20:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0026_auto_20170328_2128'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contentarticle',
            name='body1Image',
            field=models.ImageField(blank=True, null=True, upload_to='articleImages/'),
        ),
        migrations.AlterField(
            model_name='contentarticle',
            name='body2Image',
            field=models.ImageField(blank=True, null=True, upload_to='articleImages/'),
        ),
        migrations.AlterField(
            model_name='contentarticle',
            name='body3Image',
            field=models.ImageField(blank=True, null=True, upload_to='articleImages/'),
        ),
        migrations.AlterField(
            model_name='contentarticle',
            name='teaserImage',
            field=models.ImageField(blank=True, null=True, upload_to='articleImages/'),
        ),
    ]
