# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-04-11 09:13
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('omCmsMain', '0031_sitemaininfo_displaydrawrmenu'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitemaininfo',
            name='allwaysDisplayDrawrMenu',
            field=models.BooleanField(default=True),
        ),
    ]
