<h4>
    <strong>{{articleitem.title|safe}} </strong>
</h4>    
</h5>    
{% if articleitem.subTitle %} {{articleitem.subTitle|safe}} {% endif %}<br />
    {% if articleitem.teaser %}{{articleitem.teaser|safe}} {% endif %}<br />
    {{articleitem.body1|safe}}</h5>
<hr />