# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-20 15:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='categoryItems',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('itemCategory', models.CharField(max_length=50)),
                ('itemActive', models.IntegerField(default=0)),
                ('loggedOnly', models.IntegerField(default=1)),
                ('itemOrder', models.IntegerField(default=0)),
                ('itemDescription', models.CharField(blank=True, max_length=50, null=True)),
                ('itemMouseOver', models.CharField(blank=True, max_length=150, null=True)),
                ('itemLinkTo', models.CharField(blank=True, max_length=150, null=True, verbose_name='linkTo - Default: itemCategory')),
            ],
        ),
        migrations.CreateModel(
            name='siteMaininfo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('siteName', models.CharField(max_length=50)),
                ('siteLogo', models.ImageField(null=True, upload_to='media/omCmsMain/siteImages')),
                ('siteHeadBgImg', models.ImageField(null=True, upload_to='media/omCmsMain/siteImages')),
                ('siteShortDescription', models.CharField(max_length=150)),
                ('siteTagLine1', models.CharField(max_length=150)),
                ('siteTagLine2', models.CharField(max_length=150)),
                ('siteLongDescription', models.CharField(max_length=250)),
                ('siteAnalytics', models.CharField(max_length=250)),
                ('siteAdress', models.CharField(max_length=250)),
                ('sitePhone1', models.CharField(max_length=250)),
                ('sitePhone2', models.CharField(max_length=250)),
                ('siteEmail', models.CharField(max_length=250)),
            ],
        ),
        migrations.CreateModel(
            name='siteSocialMediaReferences',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('smName', models.CharField(max_length=50)),
                ('smLogo', models.ImageField(null=True, upload_to='media/omCmsMain/siteImages')),
                ('smLink', models.CharField(max_length=100)),
            ],
        ),
    ]
