<h4>
  <strong>{{articleitem.title|safe}} </strong>
</h4>    
    
{% if articleitem.subTitle %} <h5>{{articleitem.subTitle|safe}} </h5> {% endif %}
    {% if articleitem.teaser %}<p>{{articleitem.teaser|safe}} </p> {% endif %}
    {% if articleitem.teaserImage %}
        <img src="{{articleitem.teaserImage.url}}" /> 
    {% endif %}
    {% if articleitem.body1 %}<p>{{articleitem.body1|safe}}</p>{% endif %}
    <hr />
